﻿using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Text;
using System.IO;
using System.Reflection;
using System.Text;
using System.Threading;
using System.Windows.Forms;
using System.Runtime.InteropServices;

namespace FontTest
{
    public partial class Form1 : Form
    {
        /// <summary>
        /// Loads a font from a font file
        /// </summary>
        [DllImport("coredll.dll")]
        static extern int AddFontResource(string lpszFilename);

        /// <summary>
        /// Form constructor
        /// </summary>
        public Form1()
        {
            InitializeComponent();
        }

        /// <summary>
        /// Returns the current working directory.  Compact Framework style.
        /// </summary>
        private string GetCurrentDirectory()
        {
            return Path.GetDirectoryName(Assembly.GetExecutingAssembly().GetName().CodeBase);
        }

        /// <summary>
        /// Form Load event handler.
        /// </summary>
        private void Form1_Load(object sender, EventArgs e)
        {
            string fontFilePath =  Path.Combine(GetCurrentDirectory(), "Champignon.ttf");

            //Load the font
            if (AddFontResource(fontFilePath) == 0)
            {
                MessageBox.Show("Could not load font " + fontFilePath);
            }

            //Update the list of installed fonts
            RefreshInstalledFonts();

            //Refresh the label with the selected font
            UpdateLabelFont();
        }

        /// <summary>
        /// Populate the combobox with the list of installed fonts
        /// </summary>
        private void RefreshInstalledFonts()
        {
            InstalledFontCollection fonts = new InstalledFontCollection();
            comboBox1.DataSource = fonts.Families;
            comboBox1.DisplayMember = "Name";
        }

        /// <summary>
        /// Change the font of the label to the font selected in the combobox
        /// </summary>
        private void UpdateLabelFont()
        {
            label1.Font = new Font((FontFamily)comboBox1.SelectedValue, label1.Font.Size, label1.Font.Style);
        }

        /// <summary>
        /// ComboBox1 selection changed event handler
        /// </summary>
        private void comboBox1_SelectedIndexChanged(object sender, EventArgs e)
        {
            UpdateLabelFont();
        }
    }
}